==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Gnder");
define("_FYOURNAME","sminiz:");
define("_FYOUREMAIL","E-mail Adresiniz:");
define("_FFRIENDNAME","Arkadanzn smi:");
define("_FFRIENDEMAIL","Arkadanzn E-mail'i:");
define("_HELLO","Merhaba");
define("_YOURFRIEND","Arkadasiniz");
define("_RECOMMEND","Bu Siteyi Arkadana ner");
define("_INTSITE","ilginc bir site:");
define("_OURSITE","sitemiz olan");
define("_INTSENT","adli siteyi ilginc buldu ve size gondermek istedi.");
define("_FSITENAME","Site smi:");
define("_FSITEURL","Site Adresi:");
define("_FREFERENCE","Referansmzn gnerildii kii:");
define("_THANKSREC","Bizi nerdiiniz iin teekkrler!");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-turkish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Gnder");
define("_FYOURNAME","sminiz:");
define("_FYOUREMAIL","E-mail Adresiniz:");
define("_FFRIENDNAME","Arkadanzn smi:");
define("_FFRIENDEMAIL","Arkadanzn E-mail'i:");
define("_HELLO","Merhaba");
define("_YOURFRIEND","Arkadasiniz");
define("_RECOMMEND","Bu Siteyi Arkadana ner");
define("_INTSITE","ilginc bir site:");
define("_OURSITE","sitemiz olan");
define("_INTSENT","adli siteyi ilginc buldu ve size gondermek istedi.");
define("_FSITENAME","Site smi:");
define("_FSITEURL","Site Adresi:");
define("_FREFERENCE","Referansmzn gnerildii kii:");
define("_THANKSREC","Bizi nerdiiniz iin teekkrler!");

?>
